@@ -7,7 +7,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Readonly;
 use Perl::Critic::Utils qw( is_hash_key $SEVERITY_MEDIUM );
@@ -62,8 +62,7 @@ sub violates
     my $value         = q{[(]?\s*[01]\s*[)]?};
     my $opt_condition = q{(?:(?:if|unless)\s*[(]?\s*.+\s*[)]?\s*)?};
 
-    # regex /aa requires Perl 5.14
-    my $regex = qr/^\s*$return\s*$value\s*$opt_condition\s*;/ixmso;    ## no critic (RegularExpressions::RequireDefault)
+    my $regex = qr/^\s*$return\s*$value\s*$opt_condition\s*;/ixmso;
 
     if ( $return_line_content !~ $regex ) {
         return;
